@@ -15,6 +15,8 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='theme',
             name='related_modal_close_button_visible',
-            field=models.BooleanField(default=True, verbose_name='close button visible'),
+            field=models.BooleanField(
+                default=True,
+                verbose_name='close button visible'),
         ),
     ]
